<?php

namespace Chat\Model;

/**
 * Holds one entry in the conversation.
 */
class Entry implements \JsonSerializable {

    private $nick_name;
    private $msg;
    private $timestamp;

    /**
     * 
     * @param string $nick_name The author's nick name.
     * @param string $msg       The message, may contain multiple lines. The lines must be 
     *                           separated by a newline character (ASCCI code 10).
     */
    public function __construct($nick_name, $msg) {
        $this->nick_name = $nick_name;
        $this->msg = \explode("\n", $msg);
        $this->timestamp = time();
    }

    /**
     * @return string The author's nick name.
     */
    public function getNickName() {
        return $this->nick_name;
    }

    /**
     * @return array An array where each element is a line in the message.
     */
    public function getMsg() {
        return $this->msg;
    }

    /**
     * @return int The time when this entry was submitted.
     */
    public function getTimestamp() {
        return $this->timestamp;
    }

    /**
     * Create a JSON representation of this object.
     * 
     * @return \StdClass An object of an anonymous class that contains all properties of this object
     *                   and can be encoded with \json_encode. 
     */
    public function jsonSerialize() {
        $json_obj = new \stdClass;
        $json_obj->author = $this->nick_name;
        $json_obj->msg = $this->msg;
        $json_obj->timestamp = $this->timestamp;
        return $json_obj;
    }

}
